==> brmo-stufbg204-1.6.2-sources.jar: nl/egem/stuf/stuf0204/ObjectFactory.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.egem.stuf.stuf0204 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _TransmissionError_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "transmissionError");
    private final static QName _ExtraElement_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "extraElement");
    private final static QName _StUFBerichtenSetVraagBericht_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "vraagBericht");
    private final static QName _StUFBerichtenSetAsynchroonAntwoordBericht_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "asynchroonAntwoordBericht");
    private final static QName _StUFBerichtenSetKennisgevingsBericht_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "kennisgevingsBericht");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.egem.stuf.stuf0204
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Stuurgegevens }
     * 
     */
    public Stuurgegevens createStuurgegevens() {
        return new Stuurgegevens();
    }

    /**
     * Create an instance of {@link FoutBericht }
     * 
     */
    public FoutBericht createFoutBericht() {
        return new FoutBericht();
    }

    /**
     * Create an instance of {@link Systeem }
     * 
     */
    public Systeem createSysteem() {
        return new Systeem();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Kennisgeving }
     * 
     */
    public Stuurgegevens.Kennisgeving createStuurgegevensKennisgeving() {
        return new Stuurgegevens.Kennisgeving();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Vraag }
     * 
     */
    public Stuurgegevens.Vraag createStuurgegevensVraag() {
        return new Stuurgegevens.Vraag();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Antwoord }
     * 
     */
    public Stuurgegevens.Antwoord createStuurgegevensAntwoord() {
        return new Stuurgegevens.Antwoord();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Bevestiging }
     * 
     */
    public Stuurgegevens.Bevestiging createStuurgegevensBevestiging() {
        return new Stuurgegevens.Bevestiging();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Fout }
     * 
     */
    public Stuurgegevens.Fout createStuurgegevensFout() {
        return new Stuurgegevens.Fout();
    }

    /**
     * Create an instance of {@link ExtraElement }
     * 
     */
    public ExtraElement createExtraElement() {
        return new ExtraElement();
    }

    /**
     * Create an instance of {@link StUFBerichtenSet }
     * 
     */
    public StUFBerichtenSet createStUFBerichtenSet() {
        return new StUFBerichtenSet();
    }

    /**
     * Create an instance of {@link FoutBericht.Body }
     * 
     */
    public FoutBericht.Body createFoutBerichtBody() {
        return new FoutBericht.Body();
    }

    /**
     * Create an instance of {@link BevestigingsBericht }
     * 
     */
    public BevestigingsBericht createBevestigingsBericht() {
        return new BevestigingsBericht();
    }

    /**
     * Create an instance of {@link DatumMetIndicator }
     * 
     */
    public DatumMetIndicator createDatumMetIndicator() {
        return new DatumMetIndicator();
    }

    /**
     * Create an instance of {@link TijdvakRelatie }
     * 
     */
    public TijdvakRelatie createTijdvakRelatie() {
        return new TijdvakRelatie();
    }

    /**
     * Create an instance of {@link ExtraElementen }
     * 
     */
    public ExtraElementen createExtraElementen() {
        return new ExtraElementen();
    }

    /**
     * Create an instance of {@link TijdvakGeldigheid }
     * 
     */
    public TijdvakGeldigheid createTijdvakGeldigheid() {
        return new TijdvakGeldigheid();
    }

    /**
     * Create an instance of {@link DatumMetIndicatorKerngegeven }
     * 
     */
    public DatumMetIndicatorKerngegeven createDatumMetIndicatorKerngegeven() {
        return new DatumMetIndicatorKerngegeven();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "transmissionError")
    public JAXBElement<String> createTransmissionError(String value) {
        return new JAXBElement<String>(_TransmissionError_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtraElement }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "extraElement")
    public JAXBElement<ExtraElement> createExtraElement(ExtraElement value) {
        return new JAXBElement<ExtraElement>(_ExtraElement_QNAME, ExtraElement.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "vraagBericht", scope = StUFBerichtenSet.class)
    public JAXBElement<Object> createStUFBerichtenSetVraagBericht(Object value) {
        return new JAXBElement<Object>(_StUFBerichtenSetVraagBericht_QNAME, Object.class, StUFBerichtenSet.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "asynchroonAntwoordBericht", scope = StUFBerichtenSet.class)
    public JAXBElement<Object> createStUFBerichtenSetAsynchroonAntwoordBericht(Object value) {
        return new JAXBElement<Object>(_StUFBerichtenSetAsynchroonAntwoordBericht_QNAME, Object.class, StUFBerichtenSet.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "kennisgevingsBericht", scope = StUFBerichtenSet.class)
    public JAXBElement<Object> createStUFBerichtenSetKennisgevingsBericht(Object value) {
        return new JAXBElement<Object>(_StUFBerichtenSetKennisgevingsBericht_QNAME, Object.class, StUFBerichtenSet.class, value);
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/stuf0204/ObjectFactory.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.egem.stuf.stuf0204 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _TransmissionError_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "transmissionError");
    private final static QName _ExtraElement_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "extraElement");
    private final static QName _StUFBerichtenSetKennisgevingsBericht_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "kennisgevingsBericht");
    private final static QName _StUFBerichtenSetVraagBericht_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "vraagBericht");
    private final static QName _StUFBerichtenSetAsynchroonAntwoordBericht_QNAME = new QName("http://www.egem.nl/StUF/StUF0204", "asynchroonAntwoordBericht");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.egem.stuf.stuf0204
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Stuurgegevens }
     * 
     */
    public Stuurgegevens createStuurgegevens() {
        return new Stuurgegevens();
    }

    /**
     * Create an instance of {@link FoutBericht }
     * 
     */
    public FoutBericht createFoutBericht() {
        return new FoutBericht();
    }

    /**
     * Create an instance of {@link Systeem }
     * 
     */
    public Systeem createSysteem() {
        return new Systeem();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Kennisgeving }
     * 
     */
    public Stuurgegevens.Kennisgeving createStuurgegevensKennisgeving() {
        return new Stuurgegevens.Kennisgeving();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Vraag }
     * 
     */
    public Stuurgegevens.Vraag createStuurgegevensVraag() {
        return new Stuurgegevens.Vraag();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Antwoord }
     * 
     */
    public Stuurgegevens.Antwoord createStuurgegevensAntwoord() {
        return new Stuurgegevens.Antwoord();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Bevestiging }
     * 
     */
    public Stuurgegevens.Bevestiging createStuurgegevensBevestiging() {
        return new Stuurgegevens.Bevestiging();
    }

    /**
     * Create an instance of {@link Stuurgegevens.Fout }
     * 
     */
    public Stuurgegevens.Fout createStuurgegevensFout() {
        return new Stuurgegevens.Fout();
    }

    /**
     * Create an instance of {@link FoutBericht.Body }
     * 
     */
    public FoutBericht.Body createFoutBerichtBody() {
        return new FoutBericht.Body();
    }

    /**
     * Create an instance of {@link BevestigingsBericht }
     * 
     */
    public BevestigingsBericht createBevestigingsBericht() {
        return new BevestigingsBericht();
    }

    /**
     * Create an instance of {@link StUFBerichtenSet }
     * 
     */
    public StUFBerichtenSet createStUFBerichtenSet() {
        return new StUFBerichtenSet();
    }

    /**
     * Create an instance of {@link ExtraElement }
     * 
     */
    public ExtraElement createExtraElement() {
        return new ExtraElement();
    }

    /**
     * Create an instance of {@link ExtraElementen }
     * 
     */
    public ExtraElementen createExtraElementen() {
        return new ExtraElementen();
    }

    /**
     * Create an instance of {@link DatumMetIndicator }
     * 
     */
    public DatumMetIndicator createDatumMetIndicator() {
        return new DatumMetIndicator();
    }

    /**
     * Create an instance of {@link TijdvakGeldigheid }
     * 
     */
    public TijdvakGeldigheid createTijdvakGeldigheid() {
        return new TijdvakGeldigheid();
    }

    /**
     * Create an instance of {@link TijdvakRelatie }
     * 
     */
    public TijdvakRelatie createTijdvakRelatie() {
        return new TijdvakRelatie();
    }

    /**
     * Create an instance of {@link DatumMetIndicatorKerngegeven }
     * 
     */
    public DatumMetIndicatorKerngegeven createDatumMetIndicatorKerngegeven() {
        return new DatumMetIndicatorKerngegeven();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "transmissionError")
    public JAXBElement<String> createTransmissionError(String value) {
        return new JAXBElement<String>(_TransmissionError_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtraElement }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtraElement }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "extraElement")
    public JAXBElement<ExtraElement> createExtraElement(ExtraElement value) {
        return new JAXBElement<ExtraElement>(_ExtraElement_QNAME, ExtraElement.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "kennisgevingsBericht", scope = StUFBerichtenSet.class)
    public JAXBElement<Object> createStUFBerichtenSetKennisgevingsBericht(Object value) {
        return new JAXBElement<Object>(_StUFBerichtenSetKennisgevingsBericht_QNAME, Object.class, StUFBerichtenSet.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "vraagBericht", scope = StUFBerichtenSet.class)
    public JAXBElement<Object> createStUFBerichtenSetVraagBericht(Object value) {
        return new JAXBElement<Object>(_StUFBerichtenSetVraagBericht_QNAME, Object.class, StUFBerichtenSet.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.egem.nl/StUF/StUF0204", name = "asynchroonAntwoordBericht", scope = StUFBerichtenSet.class)
    public JAXBElement<Object> createStUFBerichtenSetAsynchroonAntwoordBericht(Object value) {
        return new JAXBElement<Object>(_StUFBerichtenSetAsynchroonAntwoordBericht_QNAME, Object.class, StUFBerichtenSet.class, value);
    }

}
